@@ -3,7 +3,7 @@ Catalog search functionality
 """
 
 from pathlib import Path
-from typing import Union, List, Dict, Any
+from typing import Union, List, Dict, Any, Optional
 import warnings
 
 from geopandas import GeoDataFrame
@@ -26,24 +26,14 @@ logger = get_logger(__name__)
 
 
 # pylint: disable=duplicate-code
-class Catalog(VizTools):
+class CatalogBase:
     """
-    The Catalog class enables access to the UP42 catalog search. You can search
-    for satellite image scenes (for different sensors and criteria like cloud cover),
-    plot the scene coverage and download and plot the scene quicklooks.
-
-    Use the catalog:
-    ```python
-    catalog = up42.initialize_catalog()
-    ```
+    The base for Catalog and Tasking class, shared functionality.
     """
 
     def __init__(self, auth: Auth):
         self.auth = auth
-        self.quicklooks = None
-
-    def __repr__(self):
-        return f"Catalog(auth={self.auth})"
+        self.type: Union[str, None] = None
 
     def get_data_products(self, basic: bool = True) -> Union[Dict, List]:
         """
@@ -63,6 +53,9 @@ class Catalog(VizTools):
             collection_overview = {}
 
             for product in products:
+                if product["collection"]["type"] != self.type:
+                    continue
+
                 try:
                     if not product["collection"]["isIntegrated"]:
                         continue
@@ -92,16 +85,111 @@ class Catalog(VizTools):
 
             return collection_overview
 
+    def get_data_product_schema(self, data_product_id: str):
+        url = f"{self.auth._endpoint()}/orders/schema/{data_product_id}"
+        json_response = self.auth._request("GET", url)
+        return json_response  # Does not contain usual "data" key
+
     def get_collections(self) -> Union[Dict, List]:
         """
         Get the available data collections.
         """
         url = f"{self.auth._endpoint()}/collections"
         json_response = self.auth._request("GET", url)
-        return json_response["data"]
+        collections = [c for c in json_response["data"] if c["type"] == self.type]
+        return collections
+
+    def place_order(
+        self,
+        order_parameters: Union[dict, None],
+        track_status: bool = False,
+        report_time: int = 120,
+        **kwargs,
+    ) -> "Order":
+        """
+        Place an order.
+
+        Args:
+            order_parameters: A dictionary like {dataProduct: ..., "params": {"id": ..., "aoi": ...}}
+            track_status (bool): If set to True, will only return the Order once it is `FULFILLED` or `FAILED`.
+            report_time (int): The interval (in seconds) to query the order status if `track_status` is True.
+
+        Warning "Deprecated order parameters"
+            The use of the 'scene' and 'geometry' parameters for the data ordering is deprecated. Please use the new
+            order_parameters parameter as described above.
+
+         Warning:
+            When placing orders of items that are in archive or cold storage,
+            the order fulfillment can happen up to **24h after order placement**.
+            In such cases, please make sure to set an appropriate `report_time`.
+            You can also use `Order.track_status` on the returned object to track the status later.
+
+        Returns:
+            Order: The placed order.
+        """
+        if "scene" in kwargs or "geometry" in kwargs:
+            # Deprecated, to be removed, use order_parameters.
+            message = (
+                "The use of the 'scene' and 'geometry' parameters for the data ordering is deprecated. "
+                "Please use the new 'order_parameters' parameter."
+            )
+            warnings.warn(message, DeprecationWarning, stacklevel=2)
+        elif order_parameters is None:
+            raise ValueError("Please provide the 'order_parameters' parameter!")
+
+        order = Order.place(self.auth, order_parameters)  # type: ignore
+        if track_status:
+            order.track_status(report_time)
+        return order
+
+
+class Catalog(CatalogBase, VizTools):
+    """
+    The Catalog class enables access to the UP42 catalog functionality (data archive search & ordering).
+
+    Use tasking:
+    ```python
+    catalog = up42.initialize_catalog()
+    ```
+    """
+
+    def __init__(self, auth: Auth):
+        self.auth = auth
+        self.quicklooks = None
+        self.type = "ARCHIVE"
+        self.data_products: Union[None, dict] = None
+
+    def __repr__(self):
+        return f"Catalog(auth={self.auth})"
+
+    def estimate_order(self, order_parameters: Union[dict, None], **kwargs) -> int:
+        """
+        Estimate the cost of an order.
+
+        Args:
+            order_parameters: A dictionary like {dataProduct: ..., "params": {"id": ..., "aoi": ...}}
+
+        Returns:
+            int: An estimated cost for the order in UP42 credits.
+
+        Warning "Deprecated order parameters"
+            The use of the 'scene' and 'geometry' parameters for the data estimation is deprecated. Please use the new
+            order_parameters parameter as described above.
+        """
+        if "scene" in kwargs or "geometry" in kwargs:
+            # Deprecated, to be removed, use order_parameters.
+            message = (
+                "The use of the 'scene' and 'geometry' parameters for the data estimation is deprecated. "
+                "Please use the new 'order_parameters' parameter."
+            )
+            warnings.warn(message, DeprecationWarning, stacklevel=2)
+        elif order_parameters is None:
+            raise ValueError("Please provide the 'order_parameters' parameter!")
+        return Order.estimate(self.auth, order_parameters)  # type: ignore
 
     @deprecation("construct_search_parameters", "0.25.0")
     def construct_parameters(self, **kwargs):  # pragma: no cover
+        """Deprecated, see construct_search_parameters"""
         return self.construct_search_parameters(**kwargs)
 
     # pylint: disable=dangerous-default-value
@@ -118,14 +206,14 @@ class Catalog(VizTools):
         collections: List[str],
         start_date: str = "2020-01-01",
         end_date: str = "2020-01-30",
-        usage_type: List[str] = ["DATA", "ANALYTICS"],
+        usage_type: List[str] = None,
         limit: int = 10,
-        max_cloudcover: float = 100,
+        max_cloudcover: Optional[int] = None,
         sortby: str = "acquisitionDate",
         ascending: bool = True,
     ) -> dict:
         """
-        Follows STAC principles and property names.
+        Helps constructing the parameters dictionary required for the search.
 
         Args:
             geometry: The search geometry, one of dict, Feature, FeatureCollection,
@@ -134,15 +222,14 @@ class Catalog(VizTools):
                 Also see catalog.get_collections().
             start_date: Query period starting day, format "2020-01-01".
             end_date: Query period ending day, format "2020-01-01".
-            usage_type: Filter for imagery that can just be purchased & downloaded or also
+            usage_type: Optional. Filter for imagery that can just be purchased & downloaded or also
                 processes. ["DATA"] (can only be download), ["ANALYTICS"] (can be downloaded
                 or used directly with a processing algorithm), ["DATA", "ANALYTICS"]
                 (can be any combination). The filter is inclusive, using ["DATA"] can
                 also result in results with ["DATA", "ANALYTICS"].
             limit: The maximum number of search results to return (1-max.500).
-            max_cloudcover: Maximum cloudcover % - e.g. 100 will return all scenes,
+            max_cloudcover: Optional. Maximum cloudcover % - e.g. 100 will return all scenes,
                 8.4 will return all scenes with 8.4 or less cloudcover.
-                Ignored for collections that have no cloudcover (e.g. sentinel1).
             sortby: The property to sort by, "cloudCoverage", "acquisitionDate",
                 "acquisitionIdentifier", "incidenceAngle", "snowCover".
             ascending: Ascending sort order by default, descending if False.
@@ -158,17 +245,18 @@ class Catalog(VizTools):
         sort_order = "asc" if ascending else "desc"
 
         query_filters: Dict[Any, Any] = {}
-        if "Sentinel-1" not in collections:
+        if max_cloudcover is not None:
             query_filters["cloudCoverage"] = {"lte": max_cloudcover}  # type: ignore
 
-        if usage_type == ["DATA"]:
-            query_filters["up42:usageType"] = {"in": ["DATA"]}
-        elif usage_type == ["ANALYTICS"]:
-            query_filters["up42:usageType"] = {"in": ["ANALYTICS"]}
-        elif usage_type == ["DATA", "ANALYTICS"]:
-            query_filters["up42:usageType"] = {"in": ["DATA", "ANALYTICS"]}
-        else:
-            raise ValueError("Select correct `usage_type`")
+        if usage_type is not None:
+            if usage_type == ["DATA"]:
+                query_filters["up42:usageType"] = {"in": ["DATA"]}
+            elif usage_type == ["ANALYTICS"]:
+                query_filters["up42:usageType"] = {"in": ["ANALYTICS"]}
+            elif usage_type == ["DATA", "ANALYTICS"]:
+                query_filters["up42:usageType"] = {"in": ["DATA", "ANALYTICS"]}
+            else:
+                raise ValueError("Select correct `usage_type`")
 
         search_parameters = {
             "datetime": time_period,
@@ -214,17 +302,22 @@ class Catalog(VizTools):
 
         # The API request would fail with a limit above 500, thus 500 is forced in the initial
         # request but additional results are handled below via pagination.
-        max_limit = search_parameters["limit"]
+        try:
+            max_limit = search_parameters["limit"]
+        except KeyError:
+            logger.info("No `limit` parameter in search_parameters, using default 500.")
+            max_limit = 500
+
         if max_limit > 500:
-            search_parameters = dict(search_parameters)
             search_parameters["limit"] = 500
 
         # UP42 API can query multiple collections of the same host at once.
-        collections = self.get_collections()
+        if self.data_products is None:
+            self.data_products = self.get_data_products(basic=True)  # type: ignore
         hosts = [
-            c["hostName"]
-            for c in collections
-            if c["name"] in search_parameters["collections"]
+            v["host"]
+            for v in self.data_products.values()  # type: ignore
+            if v["collection"] in search_parameters["collections"]
         ]
         if not hosts:
             raise ValueError(
@@ -265,46 +358,90 @@ class Catalog(VizTools):
         else:
             return df.__geo_interface__
 
+    @staticmethod
+    def construct_order_parameters(
+        data_product_id: str,
+        image_id: str,
+        aoi: Optional[
+            Union[
+                dict,
+                Feature,
+                FeatureCollection,
+                list,
+                GeoDataFrame,
+                Polygon,
+            ]
+        ] = None,
+    ):
+        """
+        Helps constructing the parameters dictionary required for the catalog order.
+
+        Args:
+            data_product_id: Id of the desired UP42 data product, see `catalog.get_data_products`
+            image_id: The id of the desired image (from search results)
+            aoi: The geometry of the order, one of dict, Feature, FeatureCollection,
+                list, GeoDataFrame, Polygon. Not required for full-image products.
+
+        Returns:
+            The constructed parameters dictionary.
+
+        Example:
+            ```python
+            order_parameters=catalog.construct_order_parameters(data_product_id='647780db-5a06-4b61-b525-577a8b68bb54',
+                                                                  image_id='6434e7af-2d41-4ded-a789-fb1b2447ac92',
+                                                                  aoi={'type': 'Polygon',
+                                                                    'coordinates': (((13.375966, 52.515068),
+                                                                      (13.375966, 52.516639),
+                                                                      (13.378314, 52.516639),
+                                                                      (13.378314, 52.515068),
+                                                                      (13.375966, 52.515068)),)})
+            ```
+        """
+        order_parameters = {
+            "dataProduct": data_product_id,
+            "params": {"id": image_id},
+        }
+
+        if aoi is not None:
+            aoi = any_vector_to_fc(vector=aoi)
+            aoi = fc_to_query_geometry(fc=aoi, geometry_operation="intersects")
+            order_parameters["params"]["aoi"] = aoi  # type:ignore
+
+        return order_parameters
+
     def download_quicklooks(
         self,
         image_ids: List[str],
-        sensor: str,
+        collection: str,
         output_directory: Union[str, Path, None] = None,
     ) -> List[str]:
         """
         Gets the quicklooks of scenes from a single sensor. After download, can
-        be plotted via catalog.plot_quicklooks() or catalog.map_quicklooks().
+        be plotted via catalog.map_quicklooks() or catalog.plot_quicklooks().
 
         Args:
             image_ids: List of provider image_ids e.g. ["6dffb8be-c2ab-46e3-9c1c-6958a54e4527"].
                 Access the search results id column via `list(search_results.id)`.
-            sensor: The satellite sensor of the image_ids, one of "pleiades", "spot",
-                "sentinel1", "sentinel2", "sentinel3", "sentinel5p".
+            collection: The data collection corresponding to the image ids.
             output_directory: The file output directory, defaults to the current working
                 directory.
 
         Returns:
             List of quicklook image output file paths.
         """
-        supported_sensors = {
-            "pleiades": "oneatlas",
-            "spot": "oneatlas",
-            "sentinel1": "sobloo-image",
-            "sentinel2": "sobloo-image",
-            "sentinel3": "sobloo-image",
-            "sentinel5p": "sobloo-image",
-        }
-
-        if sensor not in list(supported_sensors.keys()):
+        if self.data_products is None:
+            self.data_products = self.get_data_products(basic=True)  # type: ignore
+        host = [
+            v["host"]
+            for v in self.data_products.values()  # type: ignore
+            if v["collection"] == collection
+        ]
+        if not host:
             raise ValueError(
-                f"Currently only these sensors are supported: "
-                f"{list(supported_sensors.keys())}"
+                f"Selected collections {collection} is not valid. See catalog.get_collections."
             )
-        provider = supported_sensors[sensor]
-        logger.info(
-            f"Getting quicklooks from provider {provider} for image_ids: "
-            f"{image_ids}"
-        )
+        host = host[0]
+        logger.info(f"Downloading quicklooks from provider {host}.")
 
         if output_directory is None:
             output_directory = Path.cwd() / f"project_{self.auth.project_id}/catalog"
@@ -319,8 +456,9 @@ class Catalog(VizTools):
         out_paths: List[str] = []
         for image_id in tqdm(image_ids):
             try:
-                url = f"{self.auth._endpoint()}/catalog/{provider}/image/{image_id}/quicklook"
-
+                url = (
+                    f"{self.auth._endpoint()}/catalog/{host}/image/{image_id}/quicklook"
+                )
                 response = self.auth._request(
                     request_type="GET", url=url, return_text=False
                 )
@@ -336,95 +474,3 @@ class Catalog(VizTools):
 
         self.quicklooks = out_paths  # pylint: disable=attribute-defined-outside-init
         return out_paths
-
-    @staticmethod
-    def construct_order_parameters(
-        data_product_id: str,
-        image_id: str,
-        aoi: Union[
-            dict,
-            Feature,
-            FeatureCollection,
-            list,
-            GeoDataFrame,
-            Polygon,
-        ],
-    ):
-        aoi = any_vector_to_fc(vector=aoi)
-        aoi = fc_to_query_geometry(fc=aoi, geometry_operation="intersects")
-        order_parameters = {
-            "dataProduct": data_product_id,
-            "params": {
-                "id": image_id,
-                "aoi": aoi,
-            },
-        }
-        return order_parameters
-
-    def estimate_order(self, order_parameters: Union[dict, None], **kwargs) -> int:
-        """
-        Estimate the cost of an order.
-
-        Args:
-            order_parameters: A dictionary like {dataProduct: ..., "params": {"id": ..., "aoi": ...}}
-
-        Returns:
-            int: An estimated cost for the order in UP42 credits.
-
-        Warning "Deprecated order parameters"
-            The use of the 'scene' and 'geometry' parameters for the data estimation is deprecated. Please use the new
-            order_parameters parameter as described above.
-        """
-        if "scene" in kwargs or "geometry" in kwargs:
-            # Deprecated, to be removed, use order_parameters.
-            message = (
-                "The use of the 'scene' and 'geometry' parameters for the data estimation is deprecated. "
-                "Please use the new 'order_parameters' parameter."
-            )
-            warnings.warn(message, DeprecationWarning, stacklevel=2)
-        elif order_parameters is None:
-            raise ValueError("Please provide the 'order_parameters' parameter!")
-        return Order.estimate(self.auth, order_parameters)  # type: ignore
-
-    def place_order(
-        self,
-        order_parameters: Union[dict, None],
-        track_status: bool = False,
-        report_time: int = 120,
-        **kwargs,
-    ) -> "Order":
-        """
-        Place an order.
-
-        Args:
-            order_parameters: A dictionary like {dataProduct: ..., "params": {"id": ..., "aoi": ...}}
-            track_status (bool): If set to True, will only return the Order once it is `FULFILLED` or `FAILED`.
-            report_time (int): The interval (in seconds) to query the order status if `track_status` is True.
-
-        Warning "Deprecated order parameters"
-            The use of the 'scene' and 'geometry' parameters for the data ordering is deprecated. Please use the new
-            order_parameters parameter as described above.
-
-         Warning:
-            When placing orders of items that are in archive or cold storage,
-            the order fulfillment can happen up to **24h after order placement**.
-            In such cases, please make sure to set an appropriate `report_time`.
-            You can also use `Order.track_status` on the returned object to track the status later.
-
-        Returns:
-            Order: The placed order.
-        """
-        if "scene" in kwargs or "geometry" in kwargs:
-            # Deprecated, to be removed, use order_parameters.
-            message = (
-                "The use of the 'scene' and 'geometry' parameters for the data ordering is deprecated. "
-                "Please use the new 'order_parameters' parameter."
-            )
-            warnings.warn(message, DeprecationWarning, stacklevel=2)
-        elif order_parameters is None:
-            raise ValueError("Please provide the 'order_parameters' parameter!")
-
-        order = Order.place(self.auth, order_parameters)  # type: ignore
-        if track_status:
-            order.track_status(report_time)
-        return order
