@@ -82,7 +82,7 @@ class VizTools:
     def plot_results(
         self,
         figsize: Tuple[int, int] = (14, 8),
-        bands: List[int] = [1, 2, 3],
+        bands: Optional[List[int]] = None,
         titles: Optional[List[str]] = None,
         filepaths: Union[List[Union[str, Path]], dict, None] = None,
         plot_file_format: List[str] = [".tif"],
@@ -94,7 +94,7 @@ class VizTools:
 
         Args:
             figsize: matplotlib figure size.
-            bands: Image bands and order to plot, default [1,2,3]. First band is 1.
+            bands: Image bands and order to plot, e.g. [1,2,3]. First band is 1.
             titles: Optional list of titles for the subplots.
             filepaths: Paths to images to plot. Optional, by default picks up the last
                 downloaded results.
@@ -145,12 +145,17 @@ class VizTools:
         else:
             axs = [axs]
 
-        if len(bands) != 3:
-            if len(bands) == 1:
-                if "cmap" not in kwargs:
-                    kwargs["cmap"] = "gray"
-            else:
-                raise ValueError("Parameter bands can only contain one or three bands.")
+        if bands is None:
+            with rasterio.open(imagepaths[0]) as src:
+                if src.count == 1:
+                    bands = [1]
+                else:
+                    bands = [1, 2, 3]
+        if len(bands) == 1:
+            kwargs["cmap"] = "gray"
+        if len(bands) not in [1, 3]:
+            raise ValueError("Parameter bands can only contain one or three bands.")
+
         for idx, (fp, title) in enumerate(zip(imagepaths, titles)):
             with rasterio.open(fp) as src:
                 img_array = src.read(bands)
@@ -179,11 +184,10 @@ class VizTools:
         respective object, e.g. job, catalog).
 
         Args:
-                figsize: matplotlib figure size.
-                filepaths: Paths to images to plot. Optional, by default picks up the last
-                        downloaded results.
-                titles: List of titles for the subplots, optional.
-
+            figsize: matplotlib figure size.
+            filepaths: Paths to images to plot. Optional, by default picks up the last
+                    downloaded results.
+            titles: List of titles for the subplots, optional.
         """
         if filepaths is None:
             if self.quicklooks is None:
@@ -197,12 +201,13 @@ class VizTools:
             titles=titles,
         )
 
+    # pylint: disable=too-many-statements
     @staticmethod
     def _map_images(
         plot_file_format: List[str],
         result_df: GeoDataFrame,
         filepaths: List[Union[str, Path]],
-        bands: List[int] = [1, 2, 3],
+        bands: Optional[List[int]] = None,
         aoi: Optional[GeoDataFrame] = None,
         show_images=True,
         show_features=False,
@@ -217,6 +222,7 @@ class VizTools:
             aoi: GeoDataFrame of aoi.
             filepaths: Paths to images to plot. Optional, by default picks up the last
                 downloaded results.
+            bands: Image bands and order to plot, e.g. [1,2,3]. First band is 1.
             show_images: Shows images if True (default).
             show_features: Show features if True. For quicklooks maps is set to False.
             name_column: Name of the feature property that provides the Feature/Layer name.
@@ -279,10 +285,14 @@ class VizTools:
                 f.add_to(m)
 
         if show_images and raster_filepaths:
-            if len(bands) != 3:
-                if len(bands) == 1:
-                    bands = bands * 3  # plot as grayband
-                else:
+            if bands is None:
+                with rasterio.open(raster_filepaths[0]) as src:
+                    if src.count == 1:
+                        bands = [1]
+                        bands = bands * 3  # visualize as grayband in folium
+                    else:
+                        bands = [1, 2, 3]
+                if len(bands) not in [1, 3]:
                     raise ValueError(
                         "Parameter bands can only contain one or three bands."
                     )
@@ -324,8 +334,8 @@ class VizTools:
     @requires_viz
     def map_results(
         self,
-        bands=[1, 2, 3],
-        aoi: GeoDataFrame = None,
+        bands: Optional[List[int]] = None,
+        aoi: Optional[GeoDataFrame] = None,
         show_images: bool = True,
         show_features: bool = True,
         name_column: str = "uid",
@@ -335,7 +345,7 @@ class VizTools:
         Displays data.json, and if available, one or multiple results geotiffs.
 
         Args:
-            bands: Image bands and order to plot, default [1,2,3]. First band is 1.
+            bands: Image bands and order to plot, e.g. [1,2,3]. First band is 1.
             aoi: Optional visualization of aoi boundaries when given GeoDataFrame of aoi.
             show_images: Shows images if True (default).
             show_features: Shows features if True (default).
